@@ -23,19 +23,17 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv7-a -mfloat-abi=hard '
-           '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong -fno-plt',
+           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+           '-fno-semantic-interposition -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                     '-pipe -fstack-protector-strong -fno-plt '
-                     '-fno-semantic-interposition',
+                     '-pipe -fno-plt -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -50,8 +48,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 "
-                '-pipe -fstack-protector-strong -fno-plt '
-                "-fno-semantic-interposition' "
+                "-pipe -fno-plt -fno-semantic-interposition' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
                 "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
@@ -639,13 +636,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
-                             '-fno-semantic-interposition -march=armv7-a '
+                             '-fno-plt -fno-semantic-interposition '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 '
+                             '-O3 -pipe -fno-plt -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration  '
                              '-I./Include/internal -I. -I./Include '
@@ -653,11 +649,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
+              '-fno-plt -fno-semantic-interposition -march=armv7-a '
+              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
               '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
@@ -665,14 +660,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt '
-                   '-fno-semantic-interposition -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-pipe -fno-plt -fno-semantic-interposition -march=armv7-a '
+                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
+                   '-fno-plt -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
@@ -689,14 +681,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -fno-semantic-interposition -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                        '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                        '-fno-semantic-interposition -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe -fno-plt '
+                        '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
+                        '-pipe -fno-plt -std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
                         '-I./Include/internal -I. -I./Include '
                         '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC',
